@@ -200,7 +200,7 @@ def skeleton(test: "Type of test" = "",
         {
         },
         'passed': False,
-        'problem': False,
+        'problems': False,
         'testType': test,
         'institution': None
     }
